# clementine

[![License][license_badge]][license_link]
[![PyPI][pypi_badge]][pypi_link]
[![Repo Size][repo_size_badge]][repo_size_link]
[![Docs][docs_badge]][docs_link]
[![Release][release_badge]][release_link]

Clementine is a sweet little Python package. It's just for fun and shouldn't
be used for anything serious.

## Installation

Installing with pip:

```sh
pip install clementine
```

## License

Copyright &copy; 2023 [Suzen Fylke](https://suzenfylke.com). Distributed under the MIT License.


[docs_badge]: https://img.shields.io/github/actions/workflow/status/codesue/clementine/publish-docs.yml?label=docs&colorA=363a4f&colorB=b7bdf8&style=flat
[docs_link]: https://github.com/codesue/clementine/actions/workflows/publish-docs.yml

[license_badge]: https://img.shields.io/github/license/codesue/clementine?colorA=363a4f&colorB=b7bdf8&style=flat
[license_link]: https://github.com/codesue/clementine/tree/main/LICENSE

[pypi_badge]: https://img.shields.io/pypi/v/clementine?colorA=363a4f&colorB=b7bdf8&style=flat
[pypi_link]: https://pypi.org/project/clementine

[release_badge]: https://img.shields.io/github/actions/workflow/status/codesue/clementine/publish-pypi.yml?label=release&colorA=363a4f&colorB=b7bdf8&style=flat
[release_link]: https://github.com/codesue/clementine/actions/workflows/publish-pypi.yml

[repo_size_badge]: https://img.shields.io/github/repo-size/codesue/clementine?colorA=363a4f&colorB=b7bdf8&style=flat
[repo_size_link]: https://github.com/codesue/clementine
